==> zio-aws-cognitosync_2.12-5.17.126.2-sources.jar: zio/aws/cognitosync/model/ListRecordsResponse.scala <==
package zio.aws.cognitosync.model
import zio.aws.cognitosync.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListRecordsResponse(
    records: Option[Iterable[zio.aws.cognitosync.model.Record]] = None,
    nextToken: Option[String] = None,
    count: Option[Integer] = None,
    datasetSyncCount: Option[Long] = None,
    lastModifiedBy: Option[String] = None,
    mergedDatasetNames: Option[Iterable[String]] = None,
    datasetExists: Option[Boolean] = None,
    datasetDeletedAfterRequestedSyncCount: Option[Boolean] = None,
    syncSessionToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitosync.model.ListRecordsResponse = {
    import ListRecordsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitosync.model.ListRecordsResponse
      .builder()
      .optionallyWith(
        records.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.records)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        count.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.count)
      .optionallyWith(datasetSyncCount.map(value => value: java.lang.Long))(
        _.datasetSyncCount
      )
      .optionallyWith(lastModifiedBy.map(value => value: java.lang.String))(
        _.lastModifiedBy
      )
      .optionallyWith(
        mergedDatasetNames.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.mergedDatasetNames)
      .optionallyWith(datasetExists.map(value => value: java.lang.Boolean))(
        _.datasetExists
      )
      .optionallyWith(
        datasetDeletedAfterRequestedSyncCount.map(value =>
          value: java.lang.Boolean
        )
      )(_.datasetDeletedAfterRequestedSyncCount)
      .optionallyWith(syncSessionToken.map(value => value: java.lang.String))(
        _.syncSessionToken
      )
      .build()
  }
  def asReadOnly: zio.aws.cognitosync.model.ListRecordsResponse.ReadOnly =
    zio.aws.cognitosync.model.ListRecordsResponse.wrap(buildAwsValue())
}
object ListRecordsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitosync.model.ListRecordsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cognitosync.model.ListRecordsResponse =
      zio.aws.cognitosync.model.ListRecordsResponse(
        records.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value),
        count.map(value => value),
        datasetSyncCount.map(value => value),
        lastModifiedBy.map(value => value),
        mergedDatasetNames.map(value => value),
        datasetExists.map(value => value),
        datasetDeletedAfterRequestedSyncCount.map(value => value),
        syncSessionToken.map(value => value)
      )
    def records: Option[List[zio.aws.cognitosync.model.Record.ReadOnly]]
    def nextToken: Option[String]
    def count: Option[Integer]
    def datasetSyncCount: Option[Long]
    def lastModifiedBy: Option[String]
    def mergedDatasetNames: Option[List[String]]
    def datasetExists: Option[Boolean]
    def datasetDeletedAfterRequestedSyncCount: Option[Boolean]
    def syncSessionToken: Option[String]
    def getRecords
        : ZIO[Any, AwsError, List[zio.aws.cognitosync.model.Record.ReadOnly]] =
      AwsError.unwrapOptionField("records", records)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("count", count)
    def getDatasetSyncCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("datasetSyncCount", datasetSyncCount)
    def getLastModifiedBy: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("lastModifiedBy", lastModifiedBy)
    def getMergedDatasetNames: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("mergedDatasetNames", mergedDatasetNames)
    def getDatasetExists: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("datasetExists", datasetExists)
    def getDatasetDeletedAfterRequestedSyncCount: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "datasetDeletedAfterRequestedSyncCount",
        datasetDeletedAfterRequestedSyncCount
      )
    def getSyncSessionToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("syncSessionToken", syncSessionToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitosync.model.ListRecordsResponse
  ) extends zio.aws.cognitosync.model.ListRecordsResponse.ReadOnly {
    override val records
        : Option[List[zio.aws.cognitosync.model.Record.ReadOnly]] = scala
      .Option(impl.records())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.cognitosync.model.Record.wrap(item)
        }.toList
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
    override val count: Option[Integer] = scala
      .Option(impl.count())
      .map(value => zio.aws.cognitosync.model.primitives.Integer(value))
    override val datasetSyncCount: Option[Long] =
      scala.Option(impl.datasetSyncCount()).map(value => value: Long)
    override val lastModifiedBy: Option[String] =
      scala.Option(impl.lastModifiedBy()).map(value => value: String)
    override val mergedDatasetNames: Option[List[String]] = scala
      .Option(impl.mergedDatasetNames())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val datasetExists: Option[Boolean] =
      scala.Option(impl.datasetExists()).map(value => value: Boolean)
    override val datasetDeletedAfterRequestedSyncCount: Option[Boolean] = scala
      .Option(impl.datasetDeletedAfterRequestedSyncCount())
      .map(value => value: Boolean)
    override val syncSessionToken: Option[String] =
      scala.Option(impl.syncSessionToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitosync.model.ListRecordsResponse
  ): zio.aws.cognitosync.model.ListRecordsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cognitosync_2.12-5.17.157.2-sources.jar: zio/aws/cognitosync/model/ListRecordsResponse.scala <==
package zio.aws.cognitosync.model
import zio.aws.cognitosync.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListRecordsResponse(
    records: Option[Iterable[zio.aws.cognitosync.model.Record]] = None,
    nextToken: Option[String] = None,
    count: Option[Integer] = None,
    datasetSyncCount: Option[Long] = None,
    lastModifiedBy: Option[String] = None,
    mergedDatasetNames: Option[Iterable[String]] = None,
    datasetExists: Option[Boolean] = None,
    datasetDeletedAfterRequestedSyncCount: Option[Boolean] = None,
    syncSessionToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitosync.model.ListRecordsResponse = {
    import ListRecordsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitosync.model.ListRecordsResponse
      .builder()
      .optionallyWith(
        records.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.records)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(count.map(value => value: java.lang.Integer))(_.count)
      .optionallyWith(datasetSyncCount.map(value => value: java.lang.Long))(
        _.datasetSyncCount
      )
      .optionallyWith(lastModifiedBy.map(value => value: java.lang.String))(
        _.lastModifiedBy
      )
      .optionallyWith(
        mergedDatasetNames.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.mergedDatasetNames)
      .optionallyWith(datasetExists.map(value => value: java.lang.Boolean))(
        _.datasetExists
      )
      .optionallyWith(
        datasetDeletedAfterRequestedSyncCount.map(value =>
          value: java.lang.Boolean
        )
      )(_.datasetDeletedAfterRequestedSyncCount)
      .optionallyWith(syncSessionToken.map(value => value: java.lang.String))(
        _.syncSessionToken
      )
      .build()
  }
  def asReadOnly: zio.aws.cognitosync.model.ListRecordsResponse.ReadOnly =
    zio.aws.cognitosync.model.ListRecordsResponse.wrap(buildAwsValue())
}
object ListRecordsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitosync.model.ListRecordsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cognitosync.model.ListRecordsResponse =
      zio.aws.cognitosync.model.ListRecordsResponse(
        records.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value),
        count.map(value => value),
        datasetSyncCount.map(value => value),
        lastModifiedBy.map(value => value),
        mergedDatasetNames.map(value => value),
        datasetExists.map(value => value),
        datasetDeletedAfterRequestedSyncCount.map(value => value),
        syncSessionToken.map(value => value)
      )
    def records: Option[List[zio.aws.cognitosync.model.Record.ReadOnly]]
    def nextToken: Option[String]
    def count: Option[Integer]
    def datasetSyncCount: Option[Long]
    def lastModifiedBy: Option[String]
    def mergedDatasetNames: Option[List[String]]
    def datasetExists: Option[Boolean]
    def datasetDeletedAfterRequestedSyncCount: Option[Boolean]
    def syncSessionToken: Option[String]
    def getRecords
        : ZIO[Any, AwsError, List[zio.aws.cognitosync.model.Record.ReadOnly]] =
      AwsError.unwrapOptionField("records", records)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("count", count)
    def getDatasetSyncCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("datasetSyncCount", datasetSyncCount)
    def getLastModifiedBy: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("lastModifiedBy", lastModifiedBy)
    def getMergedDatasetNames: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("mergedDatasetNames", mergedDatasetNames)
    def getDatasetExists: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("datasetExists", datasetExists)
    def getDatasetDeletedAfterRequestedSyncCount: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "datasetDeletedAfterRequestedSyncCount",
        datasetDeletedAfterRequestedSyncCount
      )
    def getSyncSessionToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("syncSessionToken", syncSessionToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitosync.model.ListRecordsResponse
  ) extends zio.aws.cognitosync.model.ListRecordsResponse.ReadOnly {
    override val records
        : Option[List[zio.aws.cognitosync.model.Record.ReadOnly]] = scala
      .Option(impl.records())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.cognitosync.model.Record.wrap(item)
        }.toList
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
    override val count: Option[Integer] =
      scala.Option(impl.count()).map(value => value: Integer)
    override val datasetSyncCount: Option[Long] =
      scala.Option(impl.datasetSyncCount()).map(value => value: Long)
    override val lastModifiedBy: Option[String] =
      scala.Option(impl.lastModifiedBy()).map(value => value: String)
    override val mergedDatasetNames: Option[List[String]] = scala
      .Option(impl.mergedDatasetNames())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val datasetExists: Option[Boolean] =
      scala.Option(impl.datasetExists()).map(value => value: Boolean)
    override val datasetDeletedAfterRequestedSyncCount: Option[Boolean] = scala
      .Option(impl.datasetDeletedAfterRequestedSyncCount())
      .map(value => value: Boolean)
    override val syncSessionToken: Option[String] =
      scala.Option(impl.syncSessionToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitosync.model.ListRecordsResponse
  ): zio.aws.cognitosync.model.ListRecordsResponse.ReadOnly = new Wrapper(impl)
}
